diff OrthancCppClient/main.cpp @ 60:77aec9be0a51 orthanc-renaming

renaming of cppclient
author Sebastien Jodogne <s.jodogne@gmail.com>
date Sun, 16 Sep 2012 09:29:54 +0200
parents 4bc019d2f969
children e3a40c7846b8
line wrap: on
line diff
--- a/OrthancCppClient/main.cpp	Sun Sep 16 09:28:56 2012 +0200
+++ b/OrthancCppClient/main.cpp	Sun Sep 16 09:29:54 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -32,7 +32,7 @@
 int main()
 {
   // Prepare a simple call to a Web service
-  Palanthir::HttpClient c;
+  Orthanc::HttpClient c;
   c.SetUrl("http://nominatim.openstreetmap.org/search?format=json&q=chu+liege+belgium");
   
   // Do the request and store the result in a JSON structure
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium